import os
import json
from colorama import Fore, Style

def clear_screen():
    os.system('cls' if os.name == 'nt' else 'clear')

def consulter_solde(solde):
    clear_screen()
    print(f"Solde actuel du compte : {solde}$")
    input("Appuyez sur Entrée pour revenir au menu principal.")

def ajouter_transaction(solde, transactions):
    clear_screen()
    montant = float(input("Veuillez entrer le montant de la transaction : "))
    solde += montant
    transactions.append(montant)
    print(f"Transaction ajoutée : {montant}$")
    input("Appuyez sur Entrée pour revenir au menu principal.")
    return solde

def consulter_transactions(transactions):
    clear_screen()
    print("Voici vos dernières transactions :")
    for i, transaction in enumerate(transactions):
        print(f"Transaction {i + 1}: {transaction}$")
    input("Appuyez sur Entrée pour revenir au menu principal.")

def main():
    try:
        with open('budget.json', 'r') as fichier:
            data = json.load(fichier)
        solde = data.get('solde', 0)
        transactions = data.get('transactions', [])
    except (FileNotFoundError, json.JSONDecodeError):
        solde = 0
        transactions = []

    while True:
        clear_screen()
        print(Fore.BLUE + "Bienvenue sur votre application bancaire")
        print("1. Consulter votre solde")
        print("2. Ajouter une transaction")
        print("3. Consulter vos dernières transactions")
        print("4. Quitter l'application")
        print(Style.RESET_ALL)

        choix = input("Choisissez une option : ")

        if choix == "1":
            consulter_solde(solde)
        elif choix == "2":
            solde = ajouter_transaction(solde, transactions)
        elif choix == "3":
            consulter_transactions(transactions)
        elif choix == "4":
            data = {'solde': solde, 'transactions': transactions}
            with open('budget.json', 'w') as fichier:
                json.dump(data, fichier)
            clear_screen()
            print("Données correctement enregistrées, bonne journée !")
            break
        else:
            clear_screen()
            print("Cette option est invalide. Veuillez choisir une option valide (1/2/3/4).")

if __name__ == "__main__":
    main()
